@@ -319,6 +319,7 @@ class StepRequestExtraction(object):
             >>> StepRequestExtraction.with_redis("del('key')","var_name") # 删除指定key的键值对
             >>> StepRequestExtraction.with_redis("hdel(name, k)","var_name") # 删除hash中键值对
             >>> StepRequestExtraction.with_redis("clean","var_name") # 清空redis
+            >>> StepRequestExtraction.with_redis("exists(key)","var_name") # 判断key是否存在
             >>> StepRequestExtraction.with_redis("str_get('key')","var_name") # 直接调用api
 
         """
@@ -352,6 +353,11 @@ class RequestWithOptionalArgs(object):
         self.__step_context.request.params.update(params)
         return self
 
+    def with_xml(self, xml: Text) -> "RequestWithOptionalArgs":
+        self.__step_context.request.headers["Content-Type"] = "text/xml; charset=UTF-8"
+        self.__step_context.request.data = xml
+        return self
+
     def with_headers(self, **headers) -> "RequestWithOptionalArgs":
         self.__step_context.request.headers.update(headers)
         return self
@@ -438,6 +444,7 @@ class RequestWithOptionalArgs(object):
             >>> RequestWithOptionalArgs.teardown_redis("del('key')") # 删除指定key的键值对
             >>> RequestWithOptionalArgs.teardown_redis("hdel(name, k)") # 删除hash中键值对
             >>> RequestWithOptionalArgs.teardown_redis("clean") # 清空redis
+            >>> RequestWithOptionalArgs.teardown_redis("exists(key)","var_name") # 判断key是否存在
             >>> RequestWithOptionalArgs.teardown_redis("str_get('key')") # 直接调用api
 
         """
@@ -523,7 +530,8 @@ class RunRequest(object):
             >>> RunRequest.setup_redis("del('key')") # 删除指定key的键值对
             >>> RunRequest.setup_redis("hdel(name, k)") # 删除hash中键值对
             >>> RunRequest.setup_redis("clean") # 清空redis
-            >>> RunRequest.setup_redis("str_get('key')","var_name") # 直接调用api
+            >>> RunRequest.setup_redis("exists(key)") # 判断key是否存在
+            >>> RunRequest.setup_redis("str_get('key')") # 直接调用api
 
         """
         self.__step_context.setup.append("redis:" + redis)
